import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.util.List;


/**
 * A proton wave that expands and destroys things in its path.
 * 
 * @author Michael Kolling
 * @version 0.1
 */
public class ProtonWave extends Actor
{
    /** The damage this wave will deal */
    private static final int DAMAGE = 30;
    
    /** How many images should be used in the animation of the wave */
    private static final int NUMBER_IMAGES= 30;
    
    private int imageCount = 0;    
    
    private static final int damage = 16;    
    
    /** 
     * The images of the wave. This is static so the images are not
     * recreated for every object (improves performance significantly).
     */
    private static GreenfootImage[] images;
    
    /**
     * Create a new proton wave.
     */
    public ProtonWave() 
    {
        setImage(images[0]);

        Greenfoot.playSound("proton.wav");
    }
    
    /** 
     * Create the images for expanding the wave.
     */
    public static void initializeImages() 
    {
        if(images == null) 
        {
            GreenfootImage baseImage = new GreenfootImage("wave.png");
            images = new GreenfootImage[NUMBER_IMAGES];
            for (int i = 0; i < NUMBER_IMAGES; i++) 
            {
                int size = (i+1) * ( baseImage.getWidth() / NUMBER_IMAGES );
                images[i] = new GreenfootImage(baseImage);
                images[i].scale(size, size);
            }
        }
    }
    
    /**
     * Act for the proton wave is: grow and check whether we hit anything.
     */
    public void act()
    { 
        grow();
    }
    
    /**
     * Grow the proton wave.
     * Check for collisions with each new size.
     */
    private void grow()
    {
        setImage(images[imageCount]);
        checkCollision((images[imageCount].getWidth())/2);
        
        imageCount += 1;
        if (imageCount >= NUMBER_IMAGES)
        {
            getWorld().removeObject(this);
        }
    }
    
    /**
     * Check if wave is touching any objects
     * If so, damage those objects
     */
    private void checkCollision(int radius)
    {
        List<Asteroid> hitAsteroids = getObjectsInRange(radius, Asteroid.class);
        
        for (Asteroid a : hitAsteroids)
        {
            a.hit(DAMAGE);
        }
    }
}
