import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'space' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kolling
 * 
 * @version 1.0
 */
public class Rocket extends SmoothMover
{
    private static final int gunReloadTime = 5;         // The minimum delay between firing the gun.
    private static final int protonReloadTime = 500;

    private int reloadDelayCount;               // How long ago we fired the gun the last time.
    private int protonDelayCount;

    private int level = 1;

    private GreenfootImage rocket = new GreenfootImage("rocket.png");    
    private GreenfootImage rocketWithThrust = new GreenfootImage("rocketWithThrust.png");

    /**
     * Initilise this rocket.
     */
    public Rocket()
    {
        reloadDelayCount = 5;
        protonDelayCount = 500;        
        this.setRotation(Greenfoot.getRandomNumber(361));
        Vector x = new Vector(Greenfoot.getRandomNumber(361), .75);
        this.addForce(x);

    }

    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     */
    public void act()
    {

        Space w = (Space)getWorld();
        w.nextLevel();

        move();
        checkKeys();
        reloadDelayCount++;
        protonDelayCount++;
        checkCollision();

    }

    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        if (Greenfoot.isKeyDown("space")) 
        {
            fire();
        }
        if (Greenfoot.isKeyDown("left")) 
        {
            turn(-3);
        }
        if (Greenfoot.isKeyDown("right")) 
        {
            turn(3);
        }
        if (Greenfoot.isKeyDown("p")) 
        {
            startProtonWave();
        }
        ignite(Greenfoot.isKeyDown("up"));
    }

    private void ignite(boolean thrusterOn)
    {
        if (thrusterOn)
        {
            this.setImage(rocketWithThrust);
            Vector v = new Vector(this.getRotation(), .04);
            this.addForce(v);
        }
        else
        {
            this.setImage(rocket);
        }
    }

    /**
     * Fire a bullet if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Bullet bullet = new Bullet (getMovement().copy(), getRotation());
            getWorld().addObject (bullet, getX(), getY());
            bullet.move();
            reloadDelayCount = 0;
        }
    }

    /**
     * Checks to see if the rocket has hit anything
     * If so, place an explosion and remove the rocket
     */
    private void checkCollision()
    {
        Actor a = this.getOneIntersectingObject(Asteroid.class);
        if (a != null){
            Space w = (Space)getWorld();
            Explosion e = new Explosion();
            w.addObject(e, this.getX(), this.getY());
            w.gameOver();
            getWorld().removeObject(this);
        }
    }

    public void startProtonWave()
    {
        if (protonDelayCount >= protonReloadTime) 
        {
            Space w = (Space)getWorld();
            ProtonWave p = new ProtonWave();
            w.addObject(p, this.getX(), this.getY());
            protonDelayCount = 0;
        }
    }

}