import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.awt.Color;
import java.util.Random;
import java.util.List;

/**
 * Space. Something for rockets to fly in.
 * 
 * @author Michael Kolling
 * @version 1.0
 */
public class Space extends World
{
    private Counter c;
    private Counter lvl;
    private int startAsteroids = 2;
    private int level = 0;
    Rocket rocket = new Rocket();

    public Space()
    {
        super(600, 400, 1);
        GreenfootImage background = getBackground();
        background.setColor(Color.BLACK);
        background.fill();

        //Rocket rocket = new Rocket();
        addObject(rocket, Greenfoot.getRandomNumber(getWidth() / 3) + getWidth() / 3, Greenfoot.getRandomNumber(getHeight() / 3) + getHeight() / 3);

        addAsteroids(startAsteroids);

        c = new Counter("Score: ");
        lvl = new Counter("Level: ");
        addObject(c, 60, 380);
        addObject(lvl, 570, 380);
        lvl.add(1);

        makeStars(Greenfoot.getRandomNumber(50) + 20);

        Explosion.initializeImages();
        ProtonWave.initializeImages();

    } 

    /**
     * Add a given number of asteroids to our world. Asteroids are only added into
     * the left half of the world.
     */
    public void addAsteroids(int count) 
    {
        for(int i = 0; i < count; i++) 
        {
            int x = 0;
            if (Greenfoot.getRandomNumber(2) < 1)
            {
                x = Greenfoot.getRandomNumber(getWidth() / 3);               
            }
            else
            {
                x = getWidth() - Greenfoot.getRandomNumber(getWidth() / 3);                
            }
            int y = 0;
            if (Greenfoot.getRandomNumber(2) < 1)
            {
                y = Greenfoot.getRandomNumber(getHeight() / 3);               
            }
            else
            {
                y = getWidth() - Greenfoot.getRandomNumber(getHeight() / 3);                
            }
            addObject(new Asteroid(), x, y);
        }
    }

    /**
     * Makes background stars
     * @param numStars, number of stars you want to make
     */
    private void makeStars(int numStars)
    {
        for (int i = 0; i < numStars; i++)
        {
            GreenfootImage b = getBackground();
            b.setColor(new Color(255, 255, 255));
            int s = (int)Greenfoot.getRandomNumber(7);
            b.fillOval(Greenfoot.getRandomNumber(getWidth()), Greenfoot.getRandomNumber(getHeight()), s, s);
        }
    }

    /**
     * This method is called when the game is over to display the final score.
     */
    public void gameOver()
    {
        ScoreBoard s = new ScoreBoard(c.value);
        this.addObject(s, getWidth() / 2, getHeight() / 2);
        
    }

    public void nextLevel()
    {
        if (getObjects(Asteroid.class).isEmpty() == true)
        {  
            level++;
            
            lvl.add(1);

            rocket.setLocation(this.getWidth() / 2, this.getHeight() / 2);

            addAsteroids(level+startAsteroids);

            Greenfoot.playSound("hooray.wav");
        }
    }

    public void addScore(int score)
    {
        c.add(score);
    }
}